import { VideoUploadModel } from './http.models';
export declare class BaseModel<T> {
    success: boolean;
    error: ErrorModel;
    data: T;
}
export declare class BaseQueryModel<T> extends BaseModel<QueryModel<T>> {
}
export declare class ErrorModel {
    code: number;
    message: string;
    rows: any[];
}
export declare class QueryModel<T> {
    page: number;
    pages: number;
    totalRowsCount: number;
    rows: T[];
}
export declare class AddModel {
    id: number;
}
export declare class EditModel {
}
export declare class DeleteModel {
}
export declare class PermissionActionModel {
    name: string;
    access: boolean;
    constructor(name: string, access: boolean);
}
export declare class PermissionModel {
    name: string;
    actions: PermissionActionModel[];
    constructor(name: string, actions: PermissionActionModel[]);
}
export declare class UploadModel {
    name: string;
    extension: string;
    size: number;
}
export declare class VideoWatermarkModel {
}
export declare class VideoThumbnailModel {
    path: string;
}
export declare class VideoInfoModel {
    width: number;
    height: number;
    thumb?: string;
}
export declare class ComboModel<T> {
    value: T;
    selected: boolean;
    constructor(value: T, selected: boolean);
}
export interface SortPageModel {
    page?: number;
    pageSize?: number;
    by?: string;
    ascending?: boolean;
}
export declare class SortPaging {
    model: SortPageModel;
    private items;
    constructor(model: SortPageModel);
    getString(query?: string): string;
}
export interface VideoUploadWatermarkModel {
    wmUrl: string;
    wmX: number;
    wmY: number;
}
export interface VideoUploadThumbnailModel {
    thumbClock: string;
    thumbWidth?: number;
    thumbHeight?: number;
}
export interface VideoUploadModel {
    url?: string;
    wmUrl?: string;
    wmX?: number;
    wmY?: number;
    thumbClock?: string;
    thumbWidth?: number;
    thumbHeight?: number;
}
export declare class VideoUpload {
    model: VideoUploadModel | VideoUploadThumbnailModel;
    private items;
    constructor(model: VideoUploadModel | VideoUploadThumbnailModel);
    isVideoUploadModel(object: any): object is VideoUploadModel;
    isVideoUploadWatermarkModel(object: any): object is VideoUploadWatermarkModel;
    isVideoUploadThumbnailModel(object: any): object is VideoUploadThumbnailModel;
    getString(): string;
}
